@@ -43,7 +43,7 @@ use 5.008;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Moose;
 
@@ -410,40 +410,48 @@ extends L<IO::Moose::Seekable>
 
 =over 2
 
-=item *
+=item   *
 
 extends L<IO::Moose::Handle>
 
 =over 2
 
-=item *
+=item     *
 
 extends L<MooseX::GlobRef::Object>
 
 =over 2
 
-=item *
+=item       *
 
 extends L<Moose::Object>
 
 =back
 
-=item *
-
-extends L<IO::Handle>
-
 =back
 
-=item *
-
-extends L<IO::Seekable>
-
 =back
 
 =item *
 
 extends L<IO::File>
 
+=over 2
+
+=item   *
+
+extends L<IO::Seekable>
+
+=over 2
+
+=item     *
+
+extends L<IO::Handle>
+
+=back
+
+=back
+
 =back
 
 =head1 EXCEPTIONS
@@ -628,7 +636,7 @@ The API is not stable yet and can be changed in future.
 
 =head1 AUTHOR
 
-Piotr Roszatycki E<lt>dexter@debian.orgE<gt>
+Piotr Roszatycki <dexter@debian.org>
 
 =head1 LICENSE
 
