@@ -31,7 +31,7 @@ mode string (i.e. "+>").
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Moose::Util::TypeConstraints;
 
@@ -68,7 +68,7 @@ L<Moose::Util::TypeConstraints>, L<IO::Moose>.
 
 =head1 AUTHOR
 
-Piotr Roszatycki E<lt>dexter@debian.orgE<gt>
+Piotr Roszatycki <dexter@debian.org>
 
 =head1 LICENSE
 
