@@ -28,7 +28,7 @@ mode string (i.e. "+>") with additional PerlIO layer.
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Moose::Util::TypeConstraints;
 
@@ -54,7 +54,7 @@ L<Moose::Util::TypeConstraints>, L<IO::Moose>, L<perlio>.
 
 =head1 AUTHOR
 
-Piotr Roszatycki E<lt>dexter@debian.orgE<gt>
+Piotr Roszatycki <dexter@debian.org>
 
 =head1 LICENSE
 
