@@ -3,12 +3,15 @@ package IO::Moose::FileOpenTest;
 use strict;
 use warnings;
 
+use Test::Unit::Lite;
 use parent 'Test::Unit::TestCase';
+
 use Test::Assert ':all';
 
 use IO::Moose::Handle;
 
 use File::Temp;
+use IO::File;
 
 use Scalar::Util 'reftype', 'openhandle', 'tainted';
 
@@ -44,6 +47,14 @@ sub test_open_default_tied {
     assert_equals("package IO::Moose::FileOpenTest;\n", $obj->readline);
 };
 
+sub test_open_sysmode_tied {
+    open $obj, $filename_in, 0, 0600;
+    assert_not_null(openhandle $obj->fh);
+    assert_equals($filename_in, $obj->file);
+
+    assert_equals("package IO::Moose::FileOpenTest;\n", $obj->readline);
+};
+
 sub test_open_write {
     $obj->open($filename_out, '+>');
     assert_not_null(openhandle $obj->fh);
@@ -76,23 +87,6 @@ sub test_open_layer {
     assert_equals(":crlf", $obj->layer);
 };
 
-sub test_open_sysopen {
-    $obj->open($filename_in, 0);
-    assert_not_null(openhandle $obj->fh);
-    assert_equals($filename_in, $obj->file);
-    assert_num_equals(0, $obj->mode);
-
-    assert_equals("package IO::Moose::FileOpenTest;\n", $obj->readline);
-};
-
-sub test_open_sysopen_perms {
-    $obj->open($filename_in, 0, 0111);
-    assert_not_null(openhandle $obj->fh);
-    assert_equals($filename_in, $obj->file);
-    assert_num_equals(0, $obj->mode);
-    assert_num_equals(0111, $obj->perms);
-};
-
 sub test_open_error_io {
     assert_raises( ['Exception::IO'], sub {
         $obj->open('nosuchfile_abcdef'.$$);
@@ -116,8 +110,24 @@ sub test_open_error_args {
         $obj->open($filename_in, 0, 'string')
     } );
 
+    assert_raises( ['Exception::Argument'], sub {
+        $obj->open(\123);
+    } );
+
+    assert_raises( ['Exception::Argument'], sub {
+        $obj->open($obj);
+    } );
+
+    assert_raises( ['Exception::Argument'], sub {
+        $obj->open(\*STDIN);
+    } );
+
+    assert_raises( ['Exception::Argument'], sub {
+        $obj->open($filename_in, 'r', 3);
+    } );
+
     assert_raises( qr/does not pass the type constraint/, sub {
-        $obj->open([]);
+        $obj->open($filename_in, 0);
     } );
 
     assert_raises( qr/does not pass the type constraint/, sub {
@@ -125,6 +135,54 @@ sub test_open_error_args {
     } );
 };
 
+sub test_sysopen {
+    $obj->sysopen($filename_in, 0);
+    assert_not_null(openhandle $obj->fh);
+    assert_equals($filename_in, $obj->file);
+    assert_num_equals(0, $obj->mode);
+
+    assert_equals("package IO::Moose::FileOpenTest;\n", $obj->readline);
+};
+
+sub test_sysopen_perms {
+    $obj->sysopen($filename_in, 0, 0111);
+    assert_not_null(openhandle $obj->fh);
+    assert_equals($filename_in, $obj->file);
+    assert_num_equals(0, $obj->mode);
+    assert_num_equals(0111, $obj->perms);
+};
+
+sub test_open_syserror_io {
+    assert_raises( ['Exception::IO'], sub {
+        $obj->sysopen('nosuchfile_abcdef'.$$, 0);
+    } );
+};
+
+sub test_sysopen_error_args {
+    assert_raises( ['Exception::Argument'], sub {
+        IO::Moose::File->sysopen($filename_in, 0);
+    } );
+
+    assert_raises( ['Exception::Argument'], sub {
+        $obj->sysopen;
+    } );
+
+    assert_raises( ['Exception::Argument'], sub {
+        $obj->sysopen(\*STDIN, 0);
+    } );
+
+    assert_raises( ['Exception::Argument'], sub {
+        $obj->open($filename_in, 0, 0600, 4);
+    } );
+
+    assert_raises( qr/does not pass the type constraint/, sub {
+        $obj->sysopen($filename_in, 'r');
+    } );
+
+    assert_raises( qr/does not pass the type constraint/, sub {
+        $obj->sysopen($filename_in, 0, 'STRING');
+    } );
+};
 
 sub test_binmode {
     $obj->open($filename_out, '+>');
@@ -249,4 +307,12 @@ sub test_slurp_wantarray_object {
     $obj->close;
 };
 
+sub test_to_string {
+    $obj->open($filename_out, '+>');
+    assert_not_null(openhandle $obj->fh);
+
+    assert_equals($filename_out, $obj->to_string);
+    assert_equals($filename_out, "$obj");
+};
+
 1;
